@@ -25,12 +25,14 @@ import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.util.Locale;
 
+import junit.framework.Assert;
+
 import org.apache.commons.io.testtools.FileBasedTestCase;
 
 /**
  * This is used to test FileSystemUtils.
  *
- * @version $Id: FileSystemUtilsTestCase.java 1002819 2010-09-29 19:30:10Z niallp $
+ * @version $Id: FileSystemUtilsTestCase.java 1165968 2011-09-07 02:45:19Z ggregory $
  */
 public class FileSystemUtilsTestCase extends FileBasedTestCase {
 
@@ -69,6 +71,7 @@ public class FileSystemUtilsTestCase extends FileBasedTestCase {
             try {
                 r = new BufferedReader(new InputStreamReader(proc.getInputStream()));
                 String line = r.readLine();
+                Assert.assertNotNull("Unexpected null line", line);
                 if (line.indexOf("512") >= 0) {
                     kilobyteBlock = false;
                 }
@@ -186,7 +189,7 @@ public class FileSystemUtilsTestCase extends FileBasedTestCase {
             "17/08/2005  21:44    <DIR>          Desktop\n" +
             "               7 File(s)         180260 bytes\n" +
             "              10 Dir(s)     41411551232 bytes free";
-        FileSystemUtils fsu = new MockFileSystemUtils(0, lines, "dir /-c ");
+        FileSystemUtils fsu = new MockFileSystemUtils(0, lines, "dir /a /-c ");
         assertEquals(41411551232L, fsu.freeSpaceWindows("", -1));
     }
 
@@ -203,7 +206,7 @@ public class FileSystemUtilsTestCase extends FileBasedTestCase {
             "17/08/2005  21:44    <DIR>          Desktop\n" +
             "               7 File(s)         180260 bytes\n" +
             "              10 Dir(s)     41411551232 bytes free";
-        FileSystemUtils fsu = new MockFileSystemUtils(0, lines, "dir /-c \"C:\"");
+        FileSystemUtils fsu = new MockFileSystemUtils(0, lines, "dir /a /-c \"C:\"");
         assertEquals(41411551232L, fsu.freeSpaceWindows("C:", -1));
     }
 
@@ -220,7 +223,7 @@ public class FileSystemUtilsTestCase extends FileBasedTestCase {
             "17/08/2005  21:44    <DIR>          Desktop\n" +
             "               7 File(s)         180260 bytes\n" +
             "              10 Dir(s)     41411551232 bytes free";
-        FileSystemUtils fsu = new MockFileSystemUtils(0, lines, "dir /-c \"C:\\somedir\"");
+        FileSystemUtils fsu = new MockFileSystemUtils(0, lines, "dir /a /-c \"C:\\somedir\"");
         assertEquals(41411551232L, fsu.freeSpaceWindows("C:\\somedir", -1));
     }
 
@@ -237,7 +240,7 @@ public class FileSystemUtilsTestCase extends FileBasedTestCase {
             "17/08/2005  21:44    <DIR>          Desktop\n" +
             "               7 File(s)         180260 bytes\n" +
             "              10 Dir(s)     41411551232 bytes free";
-        FileSystemUtils fsu = new MockFileSystemUtils(0, lines, "dir /-c \"C:\\somedir\"");
+        FileSystemUtils fsu = new MockFileSystemUtils(0, lines, "dir /a /-c \"C:\\somedir\"");
         assertEquals(41411551232L, fsu.freeSpaceWindows("\"C:\\somedir\"", -1));
     }
 
